
config more[off]
spool file[p_hww05.out]


# PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)
# FACULTY:		Dan McFadden
# AUTHOR:		Peter Adams
# LAST UPDATE:		January 21, 2003
# PROGRAM DESC:		Prevalence Probits (White Males: w1)


load file[hww123]

set zero=zero
set one=one


# ====================================================================
# DEFINE INDEPENDENT VARIABLE MACROS
# ====================================================================

# AGE
# --------------------------------------------------------------------

macro p_age1 { as701, as801 }

# DEMOGRAPHICS
# --------------------------------------------------------------------

macro p_dem1 { nevmarr1, widow1, divsep1, magedie1, pagedie1, \
	smokev }

# SOCIO-ECONOMIC STATUS
# --------------------------------------------------------------------

macro p_ses1 { q1wb1, q4wb1, q1ib1, q4ib1, hs, coll, \
	hoodpf1, condpf1 }

# HEALTH CONDITIONS
# --------------------------------------------------------------------

macro p_canc1 { one }

macro p_heart1 { cancer1, one }

macro p_strk1 { cancer1, heart1, one }

macro p_lung1 { cancer1, heart1, stroke1, one }

macro p_diab1 { cancer1, heart1, stroke1, lung1, one }

macro p_high1 { cancer1, heart1, stroke1, lung1, diabet1, one }

macro p_arth1 { cancer1, heart1, stroke1, lung1, diabet1, highbp1, \
	one }

macro p_incon1 { cancer1, heart1, stroke1, lung1, diabet1, highbp1, \
	arthrt1, one }

macro p_fall1 { cancer1, heart1, stroke1, lung1, diabet1, highbp1, \
	arthrt1, incont1, one }

macro p_hip1 { cancer1, heart1, stroke1, lung1, diabet1, highbp1, \
	arthrt1, incont1, fall1, one }

macro p_prox1 { cancer1, heart1, stroke1, lung1, diabet1, highbp1, \
	arthrt1, incont1, fall1, hipfrc1, one }

macro p_cog1 { cancer1, heart1, stroke1, lung1, diabet1, highbp1, \
	arthrt1, incont1, fall1, hipfrc1, proxyw1, one }

macro p_psych1 { cancer1, heart1, stroke1, lung1, diabet1, highbp1, \
	arthrt1, incont1, fall1, hipfrc1, proxyw1, cogim1, one }

macro p_depr1 { cancer1, heart1, stroke1, lung1, diabet1, highbp1, \
	arthrt1, incont1, fall1, hipfrc1, proxyw1, cogim1, psych1, \
	one }

macro p_bmi1 { cancer1, heart1, stroke1, lung1, diabet1, highbp1, \
	arthrt1, incont1, fall1, hipfrc1, proxyw1, cogim1, psych1, \
	depres1, one }

macro p_smok1 { cancer1, heart1, stroke1, lung1, diabet1, highbp1, \
	arthrt1, incont1, fall1, hipfrc1, proxyw1, cogim1, psych1, \
	depres1, bmi1, one }

macro p_adl1 { cancer1, heart1, stroke1, lung1, diabet1, highbp1, \
	arthrt1, incont1, fall1, hipfrc1, proxyw1, cogim1, psych1, \
	depres1, bmi1, smoknow1, one }

macro p_iadl1 { cancer1, heart1, stroke1, lung1, diabet1, highbp1, \
	arthrt1, incont1, fall1, hipfrc1, proxyw1, cogim1, psych1, \
	depres1, bmi1, smoknow1, numadl1, one }

macro p_hlth1 { cancer1, heart1, stroke1, lung1, diabet1, highbp1, \
	arthrt1, incont1, fall1, hipfrc1, proxyw1, cogim1, psych1, \
	depres1, bmi1, smoknow1, numadl1, numiadl1, one }


# ====================================================================
# DEFINE DEPENDENT VARIABLE LABEL ARRAY
# ====================================================================

array a_label = ( CANCER \
	HEART \
	STROKE \
	LUNG \
	DIABETES \
	HIGH_BLOOD_PRESSURE \
	ARTHRITIS \
	INCONTINENCE \
	FALL \
	HIP_FRACTURE \
	PROXY_INTERVIEW \
	COGNITIVE_IMPAIRMENT \
	PSYCHIATRIC \
	DEPRESSION \
	BODY_MASS_INDEX \
	CURRENT_SMOKER \
	ACTIVITIES_DAILY_LIVING \
	INSTRUMENTAL_ACTIVITIES_DAILY_LIVING \
	SELF_REPORTED_HEALTH \
	NEIGHBORHOOD_CONDITION_POOR/FAIR \
	HOUSEHOLD_CONDITION_POOR/FAIR )


# ====================================================================
# DEFINE PROBIT REGRESSION MACRO
# ====================================================================

config precis[digits=5]

macro p_prev(i,a,b) {

set missing=miss(a, @p_ses1, @p_age1, @p_dem1, @b)
	
echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo i. $a_label[i] : PARAMETER ESTIMATES
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

echo
echo i.1 INCLUDE SES
echo -----------------------------------------------------------------

if(i==17) {
	probit dep[a] ind[@p_ses1 @p_age1 @p_dem1 @b] \
		maxit[50] prob[p0 p1 p2 p3 p4 p5] \
		if[(male==1)&(white==1)&(inw1==1)&(missing==0)]
	calc llk1=_llk }

if(i==18) {
	probit dep[a] ind[@p_ses1 @p_age1 @p_dem1 @b] \
		maxit[50] prob[p0 p1 p2 p3 p4] \
		if[(male==1)&(white==1)&(inw1==1)&(missing==0)]
	calc llk1=_llk }

if((i<=16)|(i>=19)) {
	probit dep[a] ind[@p_ses1 @p_age1 @p_dem1 @b] \
		maxit[50] prob[p0] coef[b0] pred[xb0] covmat[Q] \
		if[(male==1)&(white==1)&(inw1==1)&(missing==0)]
	calc llk1=_llk }

echo
echo i.2 EXCLUDE SES
echo -----------------------------------------------------------------

	probit dep[a] ind[@p_age1 @p_dem1 @b] maxit[50] \
		if[(male==1)&(white==1)&(inw1==1)&(missing==0)]
	calc llk2=_llk


echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo i. $a_label[i] : SIGNIFICANCE TESTS
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

echo
echo SES CAUSALITY TEST
echo -----------------------------------------------------------------

calc chi2=2*(llk1-llk2)
calc chi2
calc sign=1-cumchi(chi2,8)
calc sign

if((i<=16)|(i>=19)) {
echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo i. $a_label[i] : RELATIVE ODDS (SES)
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

range if[p0>0]
calc n=nobs
calc n

set z0 = b0[1]*q1wc1+b0[2]*q4wc1+b0[3]*q1ic1+b0[4]*q4ic1 \
+b0[5]*hs+b0[6]*coll+b0[7]*hoodpf1+b0[8]*condpf1; \
	if[p0>0] rp

set z1=b0[1]+b0[3]+b0[7]+b0[8]; if[p0>0] rp
set z4=b0[2]+b0[4]+b0[6]; if[p0>0] rp
#set z2=b0[5]; if[p0>0] rp

set wb1=xb0+(z1-z0); if[p0>0] rp
set wb4=xb0+(z4-z0); if[p0>0] rp
#set wb2=xb0+(z2-z0); if[p0>0] rp

set p1=cumnorm(wb1); if[p0>0] rp
set p4=cumnorm(wb4); if[p0>0] rp
#set p2=cumnorm(wb2); if[p0>0] rp

range if[(p1>0)&(p4>0)]
calc m=nobs
calc m

set r41=p4/p1; if[(p0>0)&(p1>0)&(p4>0)] rp
#set r12=p1/p2; if[(p0>0)&(p1>0)] rp
#set r42=p4/p2; if[(p0>0)&(p1>0)] rp

set k1=phi(wb1)/p1; if[(p0>0)&(p1>0)&(p4>0)] rp
set k4=phi(wb4)/p4; if[(p0>0)&(p1>0)&(p4>0)] rp
#set k2=phi(wb2)/p2; if[(p0>0)&(p1>0)] rp

set rk1=r41*k1; if[(p0>0)&(p1>0)] rp
set rk4=r41*k4; if[(p0>0)&(p1>0)] rp


# SE MATIRX CALCULATIONS: high SES (4) v. low SES (1)
# --------------------------------------------------------------------

matrix R=col(r41)
matrix K1=col(k1)
matrix K4=col(k4)
matrix RK1=R.*K1
matrix RK4=R.*K4

matrix M_SES1=col(one, zero, one, zero, zero, \
	zero, one, one)
matrix M_SES4=col(zero, one, zero, one, zero, \
	one, zero, zero)
matrix M_AGE1=col(@p_age1)
matrix M_DEM1=col(@p_dem1)	
matrix Y=col(@b)

matrix W1={M_SES1, M_AGE1, M_DEM1, Y}
matrix W4={M_SES4, M_AGE1, M_DEM1, Y}

matrix A1=RK1'
matrix A4=RK4'

matrix B4=(A4*W4)'
matrix B1=(A1*W1)'
matrix B=(B4-B1)/n
matrix V=B'*Q*B

calc se41=sqrt(V)

calc lse41=(1/mean(r41))*se41

#cova var[p0 p1 p2 p4] byvar

#echo
#echo AVERAGE RELATIVE ODDS (low SES v. mid SES)
#echo -----------------------------------------------------------------

#calc mean(r12)

#echo
#echo PERCENT CHANGE IN AVERAGE RISK (low SES v. mid SES)
#echo -----------------------------------------------------------------

#calc log(mean(r12))

#echo
#echo AVERAGE RELATIVE ODDS (high SES v. mid SES)
#echo -----------------------------------------------------------------

#calc mean(r42)

#echo
#echo PERCENT CHANGE IN AVERAGE RISK (high SES v. mid SES)
#echo -----------------------------------------------------------------

#calc log(mean(r42))

echo
echo AVERAGE RELATIVE ODDS (high SES v. low SES)
echo -----------------------------------------------------------------

calc mean(r41)
calc se41

echo
echo PERCENT CHANGE IN AVERAGE RISK (high SES v. low SES)
echo -----------------------------------------------------------------

calc log(mean(r41))
calc lse41 }

range

}


# ====================================================================
# DEFINE OLS REGRESSION MACRO
# ====================================================================

config precis[digits=5]

macro r_prev(i,a,b) {

set missing=miss(a, @p_ses1, @p_age1, @p_dem1, @b)
	
echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo i. $a_label[i] : PARAMETER ESTIMATES
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

echo
echo i.1 INCLUDE SES
echo -----------------------------------------------------------------

reg dep[a] ind[@p_ses1 @p_age1 @p_dem1 @b] rsd[rsd1] \
	if[(male==1)&(white==1)&(inw1==1)&(missing==0)]
range if[miss(rsd1)==0]
calc n=nobs
calc rss1=sum(rsd1^2)
array a_indvar = (@p_ses1 @p_age1 @p_dem1 @p_bmi1)
calc df1 = n-$#a_indvar
calc df1
range

echo
echo i.2 EXCLUDE SES
echo -----------------------------------------------------------------

reg dep[a] ind[@p_age1 @p_dem1 @b] rsd[rsd2] \
	if[(male==1)&(white==1)&(inw1==1)&(missing==0)]
calc rss2=sum(rsd2^2)

echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo i. $a_label[i] : SIGNIFICANCE TESTS
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

echo
echo SES CAUSALITY TEST
echo -----------------------------------------------------------------

calc fstat=((rss2-rss1)*df1)/(8*rss1)
calc fstat
calc sign=1-cumf(fstat,8,df1)
calc sign

}


# ====================================================================
# RUN PREVALENCE REGRESSIONS (WHITE MALES: WAVE 1)
# ====================================================================

# ********************************************************************
# ********************************************************************
@p_prev(1,cancer1,p_canc1)


# ********************************************************************
# ********************************************************************
@p_prev(2,heart1,p_heart1)


# ********************************************************************
# ********************************************************************
@p_prev(3,stroke1,p_strk1)


# ********************************************************************
# ********************************************************************
@p_prev(4,lung1,p_lung1)


# ********************************************************************
# ********************************************************************
@p_prev(5,diabet1,p_diab1)


# ********************************************************************
# ********************************************************************
@p_prev(6,highbp1,p_high1)


# ********************************************************************
# ********************************************************************
@p_prev(7,arthrt1,p_arth1)


# ********************************************************************
# ********************************************************************
@p_prev(8,incont1,p_incon1)


# ********************************************************************
# ********************************************************************
@p_prev(9,fall1,p_fall1)


# ********************************************************************
# ********************************************************************
@p_prev(10,hipfrc1,p_hip1)


# ********************************************************************
# ********************************************************************
@p_prev(11,proxyw1,p_prox1)


# ********************************************************************
# ********************************************************************
@p_prev(12,cogim1,p_cog1)


# ********************************************************************
# ********************************************************************
@p_prev(13,psych1,p_psych1)


# ********************************************************************
# ********************************************************************
@p_prev(14,depres1,p_depr1)


# ********************************************************************
# ********************************************************************
@r_prev(15,bmi1,p_bmi1)


# ********************************************************************
# ********************************************************************
@p_prev(16,smoknow1,p_smok1)


# ********************************************************************
# ********************************************************************
@p_prev(17,numadl1,p_adl1)


# ********************************************************************
# ********************************************************************
@p_prev(18,numiadl1,p_iadl1)


# ********************************************************************
# ********************************************************************
@p_prev(19,dhlth1,p_hlth1)


spool off
quit

